==> zio-aws-s3control_2.13-5.17.157.1-sources.jar: zio/aws/s3control/model/ActivityMetrics.scala <==
package zio.aws.s3control.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.s3control.model.primitives.IsEnabled
import scala.jdk.CollectionConverters._
final case class ActivityMetrics(isEnabled: Option[IsEnabled] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3control.model.ActivityMetrics = {
    import ActivityMetrics.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3control.model.ActivityMetrics
      .builder()
      .optionallyWith(
        isEnabled.map(value => IsEnabled.unwrap(value): java.lang.Boolean)
      )(_.isEnabled)
      .build()
  }
  def asReadOnly: zio.aws.s3control.model.ActivityMetrics.ReadOnly =
    zio.aws.s3control.model.ActivityMetrics.wrap(buildAwsValue())
}
object ActivityMetrics {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3control.model.ActivityMetrics
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3control.model.ActivityMetrics =
      zio.aws.s3control.model.ActivityMetrics(isEnabled.map(value => value))
    def isEnabled: Option[IsEnabled]
    def getIsEnabled: ZIO[Any, AwsError, IsEnabled] =
      AwsError.unwrapOptionField("isEnabled", isEnabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3control.model.ActivityMetrics
  ) extends zio.aws.s3control.model.ActivityMetrics.ReadOnly {
    override val isEnabled: Option[IsEnabled] = scala
      .Option(impl.isEnabled())
      .map(value => zio.aws.s3control.model.primitives.IsEnabled(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3control.model.ActivityMetrics
  ): zio.aws.s3control.model.ActivityMetrics.ReadOnly = new Wrapper(impl)
}

==> zio-aws-s3control_2.13-5.17.167.1-sources.jar: zio/aws/s3control/model/ActivityMetrics.scala <==
package zio.aws.s3control.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.s3control.model.primitives.IsEnabled
import scala.jdk.CollectionConverters._
final case class ActivityMetrics(
    isEnabled: Optional[IsEnabled] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3control.model.ActivityMetrics = {
    import ActivityMetrics.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3control.model.ActivityMetrics
      .builder()
      .optionallyWith(
        isEnabled.map(value => IsEnabled.unwrap(value): java.lang.Boolean)
      )(_.isEnabled)
      .build()
  }
  def asReadOnly: zio.aws.s3control.model.ActivityMetrics.ReadOnly =
    zio.aws.s3control.model.ActivityMetrics.wrap(buildAwsValue())
}
object ActivityMetrics {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3control.model.ActivityMetrics
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3control.model.ActivityMetrics =
      zio.aws.s3control.model.ActivityMetrics(isEnabled.map(value => value))
    def isEnabled: Optional[IsEnabled]
    def getIsEnabled: ZIO[Any, AwsError, IsEnabled] =
      AwsError.unwrapOptionField("isEnabled", isEnabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3control.model.ActivityMetrics
  ) extends zio.aws.s3control.model.ActivityMetrics.ReadOnly {
    override val isEnabled: Optional[IsEnabled] = zio.aws.core.internal
      .optionalFromNullable(impl.isEnabled())
      .map(value => zio.aws.s3control.model.primitives.IsEnabled(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3control.model.ActivityMetrics
  ): zio.aws.s3control.model.ActivityMetrics.ReadOnly = new Wrapper(impl)
}
